<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Hash;
use Auth;


class ManageWebsiteFunctionality extends Controller
{

    public function admins()
    {
        $admins = User::where('id', '!=', 1)->where('type', 'admin')->get();
        return view('admin.admins', compact('admins'));
    }

    public function saveadmins(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|unique:users,email',
            'password' => 'required|min:8'
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['type'] = "admin";
        $data['status'] = "active";
        if (isset($request->phone) && !empty($request->phone)) {
            $data['phone'] = $request->phone;
        }
        if (isset($request->address) && !empty($request->address)) {
            $data['address'] = $request->address;
        }
        $data['password'] = Hash::make($request->password);
        if ($request->hasFile('image')) {

            $validator1 = Validator::make($request->all(), [
                'image' => 'image|mimes:jpg,png,jpeg,gif,svg',
            ]);
            if ($validator1->fails()) {
                return redirect()->back()->with('error', 'Invalid Image Type !');
            }
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $data['image'] = $image_new;
        }
        $userdata = user::create($data);

        return redirect()->route('admin.admins')->with('success', 'Data Successfully Added !');
    }

    public function deleteadmin($id)
    {
        $getData = User::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/' . $getData->image))) {

            \File::delete(public_path('admin/assets/uploads/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function updateadmin(Request $request)
    {

        $EmailCheck = user::where('email', $request->email)->where('id', '!=', $request->id)->count();
        if ($EmailCheck > 0) {
            return back()->with('error', 'This email is already taken.');
            dd("stop");
        }

        $GetData = User::findOrFail($request->id);
        if (isset($request->name)) {
            $GetData->name = $request->name;
        }

        if (isset($request->phone)) {
            $GetData->phone = $request->phone;
        }

        if (isset($request->address)) {
            $GetData->address = $request->address;
        }

        if (isset($request->email)) {
            $GetData->email = $request->email;
        }
        if (isset($request->password)) {

            $validator = Validator::make($request->all(), [
                'password' => 'required|string|min:8'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Please Enter Valid Password !');
            }
            $GetData->password = Hash::make($request->password);
        }

        if ($request->hasFile('profile')) {
            $validator = Validator::make($request->all(), [
                'profile' => 'required|image|mimes:jpg,png,jpeg,gif,svg'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Profile Picture');
            }

            if (\File::exists(public_path('admin/assets/uploads/' . $GetData->image))) {

                \File::delete(public_path('admin/assets/uploads/' . $GetData->image));
            }

            $image = $request->file('profile');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/', $image_new);
            $GetData->image = $image_new;
        }

        $GetData->save();
        return back()->with('success', 'Profile Updated Successfully !');
    }

}
