<?php

namespace App\Http\Controllers;

use App\Models\Properties;
use App\Models\PropertiesImages;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class PropertiesController extends Controller
{
    public function manage_properties()
    {
        $properties = Properties::all();
        return view('admin.manage_properties', compact('properties'));
    }

    public function add_properties()
    {
        return view('admin.add_properties');
    }

    public function save_properties(Request $request)
    {
//        dd($request->all());
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'type' => 'required',
            'status' => 'required',
            'reference_number' => 'required',
            'available_date' => 'required|date',
            'rent' => 'required|numeric',
            'sourcing_fee' => 'required|numeric',
//            'monthly_occupancy_rate' => 'required|numeric',
            'short_description' => 'required',
            'overview' => 'required',
            'average_monthly_revenue' => 'required|numeric',
            'estimated_monthly_cleaning_cost' => 'required|numeric',
            'utility_council_tax' => 'required|numeric',
            'fixed_rent' => 'required|numeric',
            'estimated_profit' => 'required|numeric',
            'property_type' => 'required',
            'main_image' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }

        $data['name'] = $request->name;
        $data['type'] = $request->type;
        $data['property_type'] = $request->property_type;
        $data['slug'] = Str::slug($request->name);
        $CheckSlug = Properties::where('slug', Str::slug($request->name))->count();
        if ($CheckSlug > 0) {
            return back()->withInput()->with('error', 'This name is already exist .');
        }
        if (isset($request->area) && !empty($request->area)) {
            $data['area'] = $request->area;
        }
        if (isset($request->floors) && !empty($request->floors)) {
            $data['floors'] = $request->floors;
        }
        if (isset($request->bedrooms) && !empty($request->bedrooms)) {
            $data['bedrooms'] = $request->bedrooms;
        }
        if (isset($request->bathrooms) && !empty($request->bathrooms)) {
            $data['bathrooms'] = $request->bathrooms;
        }
        if (isset($request->terrace) && !empty($request->terrace)) {
            $data['terrace'] = $request->terrace;
        }
        if (isset($request->parking) && !empty($request->parking)) {
            $data['parking'] = $request->parking;
        }
        if (isset($request->location) && !empty($request->location)) {
            $data['location'] = $request->location;
        }
        if (isset($request->short_description) && !empty($request->short_description)) {
            $data['short_description'] = $request->short_description;
        }
        if (isset($request->overview) && !empty($request->overview)) {
            $data['overview'] = $request->overview;
        }
        if (isset($request->status) && !empty($request->status)) {
            $data['status'] = $request->status;
        }
        if (isset($request->reference_number) && !empty($request->reference_number)) {
            $data['reference_number'] = $request->reference_number;
        }
        if (isset($request->available_date) && !empty($request->available_date)) {
            $data['available_date'] = $request->available_date;
        }
        if (isset($request->rent) && !empty($request->rent)) {
            $data['rent'] = $request->rent;
        }
        if (isset($request->sourcing_fee) && !empty($request->sourcing_fee)) {
            $data['sourcing_fee'] = $request->sourcing_fee;
        }
        if (isset($request->monthly_occupancy_rate) && !empty($request->monthly_occupancy_rate)) {
            $data['monthly_occupancy_rate'] = $request->monthly_occupancy_rate;
        }
        if (isset($request->average_monthly_revenue) && !empty($request->average_monthly_revenue)) {
            $data['average_monthly_revenue'] = $request->average_monthly_revenue;
        }
        if (isset($request->estimated_monthly_cleaning_cost) && !empty($request->estimated_monthly_cleaning_cost)) {
            $data['estimated_monthly_cleaning_cost'] = $request->estimated_monthly_cleaning_cost;
        }
        if (isset($request->utility_council_tax) && !empty($request->utility_council_tax)) {
            $data['utility_council_tax'] = $request->utility_council_tax;
        }
        if (isset($request->fixed_rent) && !empty($request->fixed_rent)) {
            $data['fixed_rent'] = $request->fixed_rent;
        }
        if (isset($request->estimated_profit) && !empty($request->estimated_profit)) {
            $data['estimated_profit'] = $request->estimated_profit;
        }
        if ($request->hasFile('main_image')) {
            $validator = Validator::make($request->all(), [
                'main_image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);
            if ($validator->fails()) {
                return back()->withErrors($validator)->with('error', 'Invalid image');
            }
            $image = $request->file('main_image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/properties/', $image_new);
            $data['main_image'] = $image_new;
        }
        $record = Properties::create($data);
        return redirect()->route('admin.manage_properties')->with('success', 'Successfully Added.');
    }

    public function delete_property($id)
    {
        $getData = Properties::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/properties/' . $getData->main_image))) {
            \File::delete(public_path('admin/assets/uploads/properties/' . $getData->main_image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function edit_property($id)
    {
        $property = Properties::findOrFail(decrypt($id));
        return view('admin.edit_property', compact('property'));
    }

    public function update_properties(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'type' => 'required',
            'status' => 'required',
            'property_type' => 'required',
            'reference_number' => 'required',
            'available_date' => 'required|date',
            'rent' => 'required|numeric',
            'sourcing_fee' => 'required|numeric',
//            'monthly_occupancy_rate' => 'required|numeric',
            'short_description' => 'required',
            'overview' => 'required',
            'average_monthly_revenue' => 'required|numeric',
            'estimated_monthly_cleaning_cost' => 'required|numeric',
            'utility_council_tax' => 'required|numeric',
            'fixed_rent' => 'required|numeric',
            'estimated_profit' => 'required|numeric'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }

        $getData = Properties::findOrFail($request->id);

        $getData->slug = Str::slug($request->name);
        $getData->name = $request->name;
        $getData->property_type = $request->property_type;
        $getData->type = $request->type;
        $getData->area = $request->area;
        $getData->floors = $request->floors;
        $getData->bedrooms = $request->bedrooms;
        $getData->bathrooms = $request->bathrooms;
        $getData->terrace = $request->terrace;
        $getData->parking = $request->parking;
        $getData->location = $request->location;
        $getData->short_description = $request->short_description;
        $getData->overview = $request->overview;
        $getData->status = $request->status;
        $getData->reference_number = $request->reference_number;
        $getData->available_date = $request->available_date;
        $getData->rent = $request->rent;
        $getData->sourcing_fee = $request->sourcing_fee;
        $getData->monthly_occupancy_rate = $request->monthly_occupancy_rate;
        $getData->average_monthly_revenue = $request->average_monthly_revenue;
        $getData->estimated_monthly_cleaning_cost = $request->estimated_monthly_cleaning_cost;
        $getData->utility_council_tax = $request->utility_council_tax;
        $getData->fixed_rent = $request->fixed_rent;
        $getData->estimated_profit = $request->estimated_profit;
        if ($request->hasFile('main_image')) {
            $validator = Validator::make($request->all(), [
                'main_image' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);
            if ($validator->fails()) {
                return back()->withErrors($validator)->with('error', 'Invalid image');
            }
            if (\File::exists(public_path('admin/assets/uploads/properties/' . $getData->main_image))) {
                \File::delete(public_path('admin/assets/uploads/properties/' . $getData->main_image));
            }
            $image = $request->file('main_image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/properties/', $image_new);
            $getData->main_image = $image_new;
        }
        $getData->update();
        return redirect()->route('admin.manage_properties')->with('success', 'Successfully Updated.');
    }

    public function edit_property_images($id)
    {
        $property = Properties::findOrFail(decrypt($id));
        return view('admin.edit_property_images', compact('property'));
    }

    public function save_property_image(Request $request)
    {
        if ($request->hasFile('image')) {
            $validator = Validator::make($request->all(), [
                'image' => 'required|image|mimes:jpg,png,jpeg,gif,svg',
                'propertyid' => 'required'
            ]);
        }

        if ($validator->fails()) {
            return back()->with('error', 'Image Is Required');
        }
        $data['propertyid'] = $request->propertyid;

        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/uploads/properties/', $image_new);
            $data['image'] = $image_new;
        }

        PropertiesImages::create($data);
        return back()->with('success', 'Data Successfully Added !');
    }

    public function delete_property_image($id)
    {
        $getData = PropertiesImages::findOrFail(decrypt($id));
        if (\File::exists(public_path('admin/assets/uploads/properties/' . $getData->image))) {
            \File::delete(public_path('admin/assets/uploads/properties/' . $getData->image));
        }
        $getData->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }


}
