<?php

namespace App\Http\Controllers;

use App\Mail\ContactMessages;
use App\Mail\QuoteRequest;
use App\Models\Contactus;
use App\Models\Properties;
use App\Models\Quote;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;

class WebsiteController extends Controller
{
    public function home()
    {
        $properties = Properties::where('status', 'active')->get();
        return view("website.home", compact('properties'));
    }

    public function contact()
    {
        $setting = Setting::first();
        return view("website.contact", compact('setting'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['subject'] = $request->subject;
        $data['message'] = $request->message;
        $contactdetail = Contactus::create($data);
        $maildata = Contactus::findOrFail($contactdetail->id);
        $setting = Setting::first();
        $check = Mail::to($setting->mail_send)->send(new ContactMessages($maildata));
        if ($check) {
            return back()->with('success', 'Message Sent Successfully.');
        } else {
            return back()->with('error', 'Message Not Sent.');
        }
    }

    public function about()
    {
        return view("website.about");
    }

    public function services()
    {
        return view("website.services");
    }

    public function privacy()
    {
        $setting = Setting::first();
        return view("website.privacy", compact('setting'));
    }

    public function terms()
    {
        return view("website.terms");
    }

    public function login()
    {
        return view("website.login");
    }

    public function signup()
    {
        return view("website.signup");
    }

    public function forgot()
    {
        return view("website.forgot");
    }

    public function property(Request $request)
    {
        $query = Properties::where('status', 'active');
        if (isset($request->title) && !empty($request->title)) {
            $query->where('name', 'like', '%' . $request->title . '%');
        }
        if (isset($request->reference_number) && !empty($request->reference_number)) {
            $query->where('reference_number', 'like', '%' . $request->reference_number . '%');
        }
        if (isset($request->location) && !empty($request->location)) {
            $query->where('location', 'like', '%' . $request->location . '%');
        }
        if (isset($request->minimum_rent) && !empty($request->minimum_rent)) {
            $query->where('rent', '>=', $request->minimum_rent);
        }
        if (isset($request->maximum_rent) && !empty($request->maximum_rent)) {
            $query->where('rent', '<=', $request->maximum_rent);
        }
        $properties = $query->paginate(12);
        return view("website.property", compact('properties', 'request'));
    }

    public function propertydetails($slug)
    {
        $property = Properties::where('slug', $slug)->first();
        return view("website.propertydetails", compact('property'));
    }

    public function quote()
    {
        $setting = Setting::first();
        return view("website.quote", compact('setting'));
    }

    public function save_quote(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'company' => 'required',
            'detail' => 'required',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['company'] = $request->company;
        $data['type'] = json_encode($request->type);
        $data['detail'] = $request->detail;
        $contactdetail = Quote::create($data);
        $setting = Setting::first();
        $maildata = Quote::findOrFail($contactdetail->id);
//        return view('website.emails.quoterequest',compact('maildata'));
        $check = Mail::to($setting->mail_send)->send(new QuoteRequest($maildata));
        if ($check) {
            return back()->with('success', 'Successfully Submitted.');
        } else {
            return back()->with('error', 'Data Not Sent.');
        }
    }
}
